mlbench_core.optim
------------------

.. automodule:: mlbench_core.optim
.. currentmodule:: mlbench_core.optim


pytorch
~~~~~~~
.. automodule:: mlbench_core.optim.pytorch
.. currentmodule:: mlbench_core.optim.pytorch


optim
+++++
.. automodule:: mlbench_core.models.pytorch.optim
.. currentmodule:: mlbench_core.models.pytorch.optim


SparsifiedSGD
'''''''''''''

.. autoclass:: SparsifiedSGD
    :members:


CentralizedSparsifiedSGD
''''''''''''''''''''''''

.. autoclass:: CentralizedSparsifiedSGD
    :members:

DecentralizedSGD
''''''''''''''''

.. autoclass:: DecentralizedSGD
    :members:

CentralizedSGD
''''''''''''''

.. autoclass:: CentralizedSGD
    :members:

